@@ -26,17 +26,19 @@ int Magick::operator == ( const Magick::Geometry& left_,
 			  const Magick::Geometry& right_ )
 {
   return (
-	  ( left_.isValid()   == right_.isValid() ) &&
-	  ( left_.width()     == right_.width() ) &&
-	  ( left_.height()    == right_.height() ) &&
-	  ( left_.xOff()      == right_.xOff() ) &&
-	  ( left_.yOff()      == right_.yOff() ) &&
-	  ( left_.xNegative() == right_.xNegative() ) &&
-	  ( left_.yNegative() == right_.yNegative() ) &&
-	  ( left_.percent()   == right_.percent() ) &&
-	  ( left_.aspect()    == right_.aspect() ) &&
-	  ( left_.greater()   == right_.greater() ) &&
-	  ( left_.less()      == right_.less() )
+	  ( left_.isValid()     == right_.isValid() ) &&
+	  ( left_.width()       == right_.width() ) &&
+	  ( left_.height()      == right_.height() ) &&
+	  ( left_.xOff()        == right_.xOff() ) &&
+	  ( left_.yOff()        == right_.yOff() ) &&
+	  ( left_.xNegative()   == right_.xNegative() ) &&
+	  ( left_.yNegative()   == right_.yNegative() ) &&
+	  ( left_.percent()     == right_.percent() ) &&
+	  ( left_.aspect()      == right_.aspect() ) &&
+	  ( left_.greater()     == right_.greater() ) &&
+	  ( left_.less()        == right_.less() ) &&
+	  ( left_.fillArea()    == right_.fillArea() ) &&
+	  ( left_.limitPixels() == right_.limitPixels() )
 	  );
 }
 int Magick::operator != ( const Magick::Geometry& left_,
@@ -86,7 +88,9 @@ Magick::Geometry::Geometry ( size_t width_,
     _percent( false ),
     _aspect( false ),
     _greater( false ),
-    _less( false )
+    _less( false ),
+    _fillArea( false ),
+    _limitPixels( false )
 {
 }
 
@@ -102,7 +106,9 @@ Magick::Geometry::Geometry ( const std::string &geometry_ )
     _percent( false ),
     _aspect( false ),
     _greater( false ),
-    _less( false )
+    _less( false ),
+    _fillArea( false ),
+    _limitPixels( false )
 {
   *this = geometry_; // Use assignment operator
 }
@@ -120,24 +126,28 @@ Magick::Geometry::Geometry ( const char *geometry_ )
     _percent( false ),
     _aspect( false ),
     _greater( false ),
-    _less( false )
+    _less( false ),
+    _fillArea( false ),
+    _limitPixels( false )
 {
   *this = geometry_; // Use assignment operator
 }
 
 // Copy constructor
 Magick::Geometry::Geometry ( const Geometry &geometry_ )
-  :  _width( geometry_._width ),
-     _height( geometry_._height ),
-     _xOff( geometry_._xOff ),
-     _yOff( geometry_._yOff ),
-     _xNegative( geometry_._xNegative ),
-     _yNegative( geometry_._yNegative ),
-     _isValid ( geometry_._isValid ),
-     _percent( geometry_._percent ),
-     _aspect( geometry_._aspect ),
-     _greater( geometry_._greater ),
-     _less( geometry_._less )
+  : _width( geometry_._width ),
+    _height( geometry_._height ),
+    _xOff( geometry_._xOff ),
+    _yOff( geometry_._yOff ),
+    _xNegative( geometry_._xNegative ),
+    _yNegative( geometry_._yNegative ),
+    _isValid ( geometry_._isValid ),
+    _percent( geometry_._percent ),
+    _aspect( geometry_._aspect ),
+    _greater( geometry_._greater ),
+    _less( geometry_._less ),
+    _fillArea( geometry_._fillArea ),
+    _limitPixels( geometry_._limitPixels )
 {
 }
 
@@ -153,7 +163,9 @@ Magick::Geometry::Geometry ( void )
     _percent( false ),
     _aspect( false ),
     _greater( false ),
-    _less( false )
+    _less( false ),
+    _fillArea( false ),
+    _limitPixels( false )
 {
 }
 
@@ -178,6 +190,8 @@ Magick::Geometry& Magick::Geometry::operator = ( const Geometry& geometry_ )
       _aspect = geometry_._aspect;
       _greater = geometry_._greater;
       _less = geometry_._less;
+      _fillArea = geometry_._fillArea;
+      _limitPixels = geometry_._limitPixels;
     }
   return *this;
 }
@@ -244,7 +258,7 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
       isValid( true );
     }
 
-  if ( ( flags & XNegative ) != 0 )	
+  if ( ( flags & XNegative ) != 0 )
     _xNegative = true;
 
   if ( ( flags & YNegative ) != 0 )
@@ -262,6 +276,12 @@ Magick::Geometry::operator = ( const std::string &geometry_ )
   if ( ( flags & GreaterValue ) != 0 )
     _greater = true;
 
+  if ( ( flags & MinimumValue ) != 0 )
+    _fillArea = true;
+
+  if ( ( flags & AreaValue ) != 0 )
+    _limitPixels = true;
+
   return *this;
 }
 
@@ -282,17 +302,17 @@ Magick::Geometry::operator std::string() const
     }
 
   string geometry;
-  char buffer[32];
+  char buffer[MaxTextExtent];
 
   if ( _width )
     {
-      FormatMagickString( buffer, MaxTextExtent, "%.20g", (double) _width );
+      FormatLocaleString( buffer, MaxTextExtent, "%.20g", (double) _width );
       geometry += buffer;
     }
 
   if ( _height )
     {
-      FormatMagickString( buffer, MaxTextExtent, "%.20g",  (double) _height);
+      FormatLocaleString( buffer, MaxTextExtent, "%.20g",  (double) _height);
       geometry += 'x';
       geometry +=  buffer;
     }
@@ -304,7 +324,7 @@ Magick::Geometry::operator std::string() const
       else
         geometry += '+';
 
-      FormatMagickString( buffer, MaxTextExtent, "%+.20g", (double) _xOff);
+      FormatLocaleString( buffer, MaxTextExtent, "%.20g", (double) _xOff);
       geometry += buffer;
 
       if ( _yNegative )
@@ -312,7 +332,7 @@ Magick::Geometry::operator std::string() const
       else
         geometry += '+';
 
-      FormatMagickString( buffer, MaxTextExtent, "%+.20g", (double) _yOff);
+      FormatLocaleString( buffer, MaxTextExtent, "%.20g", (double) _yOff);
       geometry += buffer;
     }
 
@@ -328,23 +348,31 @@ Magick::Geometry::operator std::string() const
   if ( _less )
     geometry += '<';
 
+  if ( _fillArea )
+    geometry += '^';
+
+  if ( _limitPixels )
+    geometry += '@';
+
   return geometry;
 }
 
 // Construct from RectangleInfo
 Magick::Geometry::Geometry ( const MagickCore::RectangleInfo &rectangle_ )
-  : _width(static_cast<size_t>(rectangle_.width)),
-    _height(static_cast<size_t>(rectangle_.height)),
-    _xOff(static_cast<ssize_t>(rectangle_.x)),
-    _yOff(static_cast<ssize_t>(rectangle_.y)),
-    _xNegative(rectangle_.x < 0 ? true : false),
-    _yNegative(rectangle_.y < 0 ? true : false),
-    _isValid(true),
-    _percent(false),
-    _aspect(false),
-    _greater(false),
-    _less(false)
-{    
+  : _width(static_cast<size_t>( rectangle_.width )),
+    _height(static_cast<size_t>( rectangle_.height )),
+    _xOff(static_cast<ssize_t>( rectangle_.x )),
+    _yOff(static_cast<ssize_t>( rectangle_.y )),
+    _xNegative( rectangle_.x < 0 ? true : false ),
+    _yNegative( rectangle_.y < 0 ? true : false ),
+    _isValid( true ),
+    _percent( false ),
+    _aspect( false ),
+    _greater( false ),
+    _less( false ),
+    _fillArea( false ),
+    _limitPixels( false )
+{
 }
 
 // Return an ImageMagick RectangleInfo struct
