@@ -743,6 +743,19 @@ namespace Magick
     double _radius;
   };
 
+  // Merge image layers
+  class MagickPPExport mergeLayersImage : public
+    std::unary_function<Image&,void>
+  {
+  public:
+    mergeLayersImage ( ImageLayerMethod layerMethod_ );
+
+    void operator()( Image &image_ ) const;
+
+  private:
+    ImageLayerMethod _layerMethod;
+  };
+
   // Reduce image by integral size
   class MagickPPExport minifyImage : public std::unary_function<Image&,void>
   {
@@ -977,6 +990,22 @@ namespace Magick
     bool    _colorShading;
   };
 
+  // Shadow effect image (simulate an image shadow)
+  class MagickPPExport shadowImage : public std::unary_function<Image&,void>
+  {
+  public:
+    shadowImage( const double percent_opacity_ = 80, const double sigma_ = 0.5,
+      const ssize_t x_ = 5, const ssize_t y_ = 5 );
+
+    void operator()( Image &image_ ) const;
+
+  private:
+    double _percent_opacity;
+    double _sigma;
+    ssize_t _x;
+    ssize_t _y;
+  };
+
   // Sharpen pixels in image
   class MagickPPExport sharpenImage : public std::unary_function<Image&,void>
   {
@@ -1859,25 +1888,23 @@ namespace Magick
     MagickCore::Image* previous = 0;
     ::ssize_t scene = 0;
     for ( InputIterator iter = first_; iter != last_; ++iter )
-      {
-  // Unless we reduce the reference count to one, the same image
-  // structure may occur more than once in the container, causing
-  // the linked list to fail.
-  iter->modifyImage();
+    {
+      // Unless we reduce the reference count to one, the same image
+      // structure may occur more than once in the container, causing
+      // the linked list to fail.
+      iter->modifyImage();
 
-  MagickCore::Image* current = iter->image();
+      MagickCore::Image* current = iter->image();
 
-  current->previous = previous;
-  current->next     = 0;
+      current->previous = previous;
+      current->next = 0;
+      current->scene = scene++;
 
-  if ( previous != 0)
-    previous->next = current;
+      if ( previous != 0)
+        previous->next = current;
 
-  current->scene=scene;
-  ++scene;
-
-  previous = current;
-      }
+      previous = current;
+    }
   }
 
   // Remove links added by linkImages. This should be called after the
@@ -2152,7 +2179,26 @@ namespace Magick
     histogram_array=(MagickCore::ColorPacket *)
       MagickCore::RelinquishMagickMemory(histogram_array);
   }
-                      
+
+  // Combines one or more images into a single image. The grayscale value of
+  // the pixels of each image in the sequence is assigned in order to the
+  // specified channels of the combined image. The typical ordering would be
+  // image 1 => Red, 2 => Green, 3 => Blue, etc.
+  template <class InputIterator >
+  void combineImages( Image *combinedImage_,
+                      InputIterator first_,
+                      InputIterator last_,
+                      const ChannelType channel_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    linkImages( first_, last_ );
+    MagickCore::Image* image = CombineImages( first_->image(), channel_, &exceptionInfo );
+    unlinkImages( first_, last_ );
+    combinedImage_->replaceImage( image );
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
+
   // Break down an image sequence into constituent parts.  This is
   // useful for creating GIF or MNG animation sequences.
   template <class InputIterator, class Container >
@@ -2196,6 +2242,25 @@ namespace Magick
     (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
+  // Applies a value to the image with an arithmetic, relational,
+  // or logical operator to an image. Use these operations to lighten or darken
+  // an image, to increase or decrease contrast in an image, or to produce the
+  // "negative" of an image.
+  template <class InputIterator >
+  void evaluateImages( Image *evaluatedImage_,
+                       InputIterator first_,
+                       InputIterator last_,
+                       const MagickEvaluateOperator operator_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    linkImages( first_, last_ );
+    MagickCore::Image* image = EvaluateImages( first_->image(), operator_, &exceptionInfo );
+    unlinkImages( first_, last_ );
+    evaluatedImage_->replaceImage( image );
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
+
   // Merge a sequence of image frames which represent image layers.
   // This is useful for combining Photoshop layers into a single image.
   template <class InputIterator>
@@ -2312,6 +2377,23 @@ namespace Magick
     unlinkImages( first_, last_ );
     (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
+  
+  // Composes all the image layers from the current given
+  // image onward to produce a single image of the merged layers.
+  template <class InputIterator >
+  void mergeImageLayers( Image *mergedImage_,
+                         InputIterator first_,
+                         InputIterator last_,
+                         const ImageLayerMethod method_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+    linkImages( first_, last_ );
+    MagickCore::Image* image = MergeImageLayers( first_->image(), method_, &exceptionInfo );
+    unlinkImages( first_, last_ );
+    mergedImage_->replaceImage( image );
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
 
   // Create a composite image by combining several separate images.
   template <class Container, class InputIterator>
@@ -2411,6 +2493,53 @@ namespace Magick
     (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
+  // Compares each image the GIF disposed forms of the previous image in
+  // the sequence. From this it attempts to select the smallest cropped
+  // image to replace each frame, while preserving the results of the
+  // GIF animation.
+  template <class InputIterator, class Container >
+  void optimizeImageLayers( Container *optimizedImages_,
+                            InputIterator first_,
+                            InputIterator last_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+
+    linkImages( first_, last_ );
+    MagickCore::Image* images = OptimizeImageLayers( first_->image(), &exceptionInfo );
+
+    unlinkImages( first_, last_ );
+
+    optimizedImages_->clear();
+
+    insertImages( optimizedImages_, images );
+
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
+  
+  // optimizeImagePlusLayers is exactly as optimizeImageLayers, but may
+  // also add or even remove extra frames in the animation, if it improves
+  // the total number of pixels in the resulting GIF animation.
+  template <class InputIterator, class Container >
+  void optimizePlusImageLayers( Container *optimizedImages_,
+                                InputIterator first_,
+                                InputIterator last_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+
+    linkImages( first_, last_ );
+    MagickCore::Image* images = OptimizePlusImageLayers( first_->image(), &exceptionInfo );
+
+    unlinkImages( first_, last_ );
+
+    optimizedImages_->clear();
+
+    insertImages( optimizedImages_, images );
+
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
+
   // Quantize colors in images using current quantization settings
   // Set measureError_ to true in order to measure quantization error
   template <class InputIterator>
@@ -2480,6 +2609,24 @@ namespace Magick
     (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
   }
 
+  // Returns a separate grayscale image for each channel specified.
+  template <class Container >
+  void separateImages( Container *separatedImages_,
+                       const Image &image_,
+                       const ChannelType channel_ ) {
+    MagickCore::ExceptionInfo exceptionInfo;
+    MagickCore::GetExceptionInfo( &exceptionInfo );
+
+    MagickCore::Image* images = MagickCore::SeparateImages( image_.constImage(), channel_, &exceptionInfo );
+
+    separatedImages_->clear();
+
+    insertImages( separatedImages_, images );
+
+    throwException( exceptionInfo );
+    (void) MagickCore::DestroyExceptionInfo( &exceptionInfo );
+  }
+
   // Write Images
   template <class InputIterator>
   void writeImages( InputIterator first_,
