@@ -113,6 +113,7 @@ print "Composite...\n";
 $example=$model->Clone();
 $example->Label('Composite');
 $example->Composite(image=>$smile,compose=>'over',geometry=>'+35+65');
+$example->Clamp();
 push(@$images,$example);
 
 print "Contrast...\n";
@@ -130,7 +131,7 @@ push(@$images,$example);
 print "Convolve...\n";
 $example=$model->Clone();
 $example->Label('Convolve');
-$example->Convolve([1, 1, 1, 1, 4, 1, 1, 1, 1]);
+$example->Convolve([0.125, 0.125, 0.125, 0.125, 0.5, 0.125, 0.125, 0.125, 0.125]);
 push(@$images,$example);
 
 print "Crop...\n";
@@ -163,6 +164,7 @@ print "Detect Edges...\n";
 $example=$model->Clone();
 $example->Label('Detect Edges');
 $example->Edge();
+$example->Clamp();
 push(@$images,$example);
 
 print "Emboss...\n";
@@ -248,6 +250,7 @@ print "Level...\n";
 $example=$model->Clone();
 $example->Label('Level');
 $example->Level('20%x');
+$example->Clamp();
 push(@$images,$example);
 
 print "Median Filter...\n";
@@ -395,6 +398,7 @@ print "Sharpen...\n";
 $example=$model->Clone();
 $example->Label('Sharpen');
 $example->Sharpen('0.0x1.0');
+$example->Clamp();
 push(@$images,$example);
 
 print "Shave...\n";
@@ -444,6 +448,7 @@ print "Unsharp Mask...\n";
 $example=$model->Clone();
 $example->Label('Unsharp Mask');
 $example->UnsharpMask('0.0x1.0');
+$example->Clamp();
 push(@$images,$example);
 
 print "Vignette...\n";
