@@ -15,7 +15,7 @@
 %                                February 2008                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -250,19 +250,18 @@ static MagickBooleanType WriteBRAILLEImage(const ImageInfo *image_info,
       (void) WriteBlobString(image,"\n");
     }
   (void) SetImageType(image,BilevelType);
-  polarity = 0;
+  polarity=0;
   if (image->storage_class == PseudoClass) {
-    polarity=(IndexPacket) (PixelIntensityToQuantum(image,&image->colormap[0]) >=
-      (Quantum) (QuantumRange/2));
+    polarity=(IndexPacket) (GetPixelLuma(image,&image->colormap[0]) >=
+      (QuantumRange/2));
     if (image->colors == 2)
-      polarity=(IndexPacket) (PixelIntensityToQuantum(image,&image->colormap[0]) >=
-         PixelIntensityToQuantum(image,&image->colormap[1]));
+      polarity=(IndexPacket) (GetPixelLuma(image,&image->colormap[0]) >=
+        GetPixelLuma(image,&image->colormap[1]));
   }
   for (y=0; y < (ssize_t) image->rows; y+=(ssize_t) cell_height)
   {
     if ((y+cell_height) > image->rows)
       cell_height = (size_t) (image->rows-y);
-
     p=GetVirtualPixels(image,0,y,image->columns,cell_height,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
