@@ -62,6 +62,7 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
+#include "magick/pixel-accessor.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
@@ -568,7 +569,7 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 }
 
               image->colormap[1].red=image->colormap[1].green=
-                image->colormap[1].blue=(Quantum) QuantumRange;
+                image->colormap[1].blue=QuantumRange;
               for (i=0; i < (ssize_t)image->rows; i++)
                 {
                   q=QueueAuthenticPixels(image,0,i,image->columns,1,exception);
