@@ -405,6 +405,9 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
   MagickOffsetType
     scene;
 
+  MemoryInfo
+    *pixel_info;
+
   register const PixelPacket
     *p;
 
@@ -450,10 +453,10 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
       (void) TransformImageColorspace(image,sRGBColorspace);
     number_packets=(image->columns+7)/8;
-    pixels=(unsigned char *) AcquireQuantumMemory(number_packets,
-      image->rows*sizeof(*pixels));
-    if (pixels == (unsigned char *) NULL)
+    pixel_info=AcquireVirtualMemory(number_packets,image->rows*sizeof(*pixels));
+    if (pixel_info == (MemoryInfo *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+    pixels=(unsigned char *) GetVirtualMemoryBlob(pixel_info);
     /*
       Convert pixels to a bitmap.
     */
@@ -469,7 +472,7 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
       for (x=0; x < (ssize_t) image->columns; x++)
       {
         byte<<=1;
-        if (GetPixelIntensity(image,p) < (QuantumRange/2.0))
+        if (GetPixelLuma(image,p) < (QuantumRange/2.0))
           byte|=0x01;
         bit++;
         if (bit == 8)
@@ -536,7 +539,7 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     */
     jbg_enc_out(&jbig_info);
     jbg_enc_free(&jbig_info);
-    pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+    pixel_info=RelinquishVirtualMemory(pixel_info);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
     image=SyncNextImageInList(image);
