@@ -148,68 +148,69 @@ static inline ssize_t ConstrainPixel(Image *image,const ssize_t offset,
   return(offset);
 }
 
-static size_t PNMInteger(Image *image,const unsigned int base)
+static void PNMComment(Image *image)
 {
-  char
-    *comment;
-
   int
     c;
 
+  char
+    *comment;
+
   register char
     *p;
 
   size_t
-    extent,
+    extent;
+
+  /*
+    Read comment.
+  */
+  comment=AcquireString(GetImageProperty(image,"comment"));
+  extent=strlen(comment);
+  p=comment+strlen(comment);
+  for (c='#'; (c != EOF) && (c != (int) '\n'); p++)
+  {
+    if ((size_t) (p-comment+1) >= extent)
+      {
+        extent<<=1;
+        comment=(char *) ResizeQuantumMemory(comment,extent+MaxTextExtent,
+          sizeof(*comment));
+        if (comment == (char *) NULL)
+          break;
+        p=comment+strlen(comment);
+      }
+    c=ReadBlobByte(image);
+    if (c != EOF)
+      {
+        *p=(char) c;
+        *(p+1)='\0';
+      }
+  }
+  if (comment == (char *) NULL)
+    return;
+  (void) SetImageProperty(image,"comment",comment);
+  comment=DestroyString(comment);
+}
+
+static size_t PNMInteger(Image *image,const unsigned int base)
+{
+  int
+    c;
+
+  size_t
     value;
 
   /*
     Skip any leading whitespace.
   */
-  extent=MaxTextExtent;
-  comment=(char *) NULL;
-  p=comment;
   do
   {
     c=ReadBlobByte(image);
     if (c == EOF)
       return(0);
     if (c == (int) '#')
-      {
-        /*
-          Read comment.
-        */
-        if (comment == (char *) NULL)
-          comment=AcquireString((char *) NULL);
-        p=comment+strlen(comment);
-        for ( ; (c != EOF) && (c != (int) '\n'); p++)
-        {
-          if ((size_t) (p-comment+1) >= extent)
-            {
-              extent<<=1;
-              comment=(char *) ResizeQuantumMemory(comment,extent+MaxTextExtent,
-                sizeof(*comment));
-              if (comment == (char *) NULL)
-                break;
-              p=comment+strlen(comment);
-            }
-          c=ReadBlobByte(image);
-          if (c != (int) '\n')
-            {
-              *p=(char) c;
-              *(p+1)='\0';
-            }
-        }
-        if (comment == (char *) NULL)
-          return(0);
-        continue;
-      }
+      PNMComment(image);
   } while (isdigit(c) == MagickFalse);
-  if (comment != (char *) NULL)
-    {
-      (void) SetImageProperty(image,"comment",comment);
-      comment=DestroyString(comment);
-    }
   if (base == 2)
     return((size_t) (c-(int) '0'));
   /*
@@ -244,6 +245,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Quantum
     *scale;
 
+  QuantumAny
+    max_value;
+
   QuantumInfo
     *quantum_info;
 
@@ -256,7 +260,6 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   size_t
     depth,
     extent,
-    max_value,
     packet_size;
 
   ssize_t
@@ -338,6 +341,16 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           while (isspace((int) ((unsigned char) c)) != 0)
             c=ReadBlobByte(image);
+          if (c == '#')
+            {
+              /*
+                Comment.
+              */
+              PNMComment(image);
+              c=ReadBlobByte(image);
+              while (isspace((int) ((unsigned char) c)) != 0)
+                c=ReadBlobByte(image);
+            }
           p=keyword;
           do
           {
@@ -372,23 +385,23 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               if (LocaleCompare(value,"BLACKANDWHITE") == 0)
                 {
-                  SetImageColorspace(image,GRAYColorspace);
+                  (void) SetImageColorspace(image,GRAYColorspace);
                   quantum_type=GrayQuantum;
                 }
               if (LocaleCompare(value,"BLACKANDWHITE_ALPHA") == 0)
                 {
-                  SetImageColorspace(image,GRAYColorspace);
+                  (void) SetImageColorspace(image,GRAYColorspace);
                   image->matte=MagickTrue;
                   quantum_type=GrayAlphaQuantum;
                 }
               if (LocaleCompare(value,"GRAYSCALE") == 0)
                 {
-                  SetImageColorspace(image,GRAYColorspace);
+                  (void) SetImageColorspace(image,GRAYColorspace);
                   quantum_type=GrayQuantum;
                 }
               if (LocaleCompare(value,"GRAYSCALE_ALPHA") == 0)
                 {
-                  SetImageColorspace(image,GRAYColorspace);
+                  (void) SetImageColorspace(image,GRAYColorspace);
                   image->matte=MagickTrue;
                   quantum_type=GrayAlphaQuantum;
                 }
@@ -399,12 +412,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 }
               if (LocaleCompare(value,"CMYK") == 0)
                 {
-                  SetImageColorspace(image,CMYKColorspace);
+                  (void) SetImageColorspace(image,CMYKColorspace);
                   quantum_type=CMYKQuantum;
                 }
               if (LocaleCompare(value,"CMYK_ALPHA") == 0)
                 {
-                  SetImageColorspace(image,CMYKColorspace);
+                  (void) SetImageColorspace(image,CMYKColorspace);
                   image->matte=MagickTrue;
                   quantum_type=CMYKAQuantum;
                 }
@@ -434,7 +447,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert PBM image to pixel packets.
         */
-        SetImageColorspace(image,GRAYColorspace);
+        (void) SetImageColorspace(image,GRAYColorspace);
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register ssize_t
@@ -474,7 +487,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert PGM image to pixel packets.
         */
-        SetImageColorspace(image,GRAYColorspace);
+        (void) SetImageColorspace(image,GRAYColorspace);
         scale=(Quantum *) NULL;
         if (max_value != (1U*QuantumRange))
           {
@@ -505,7 +518,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             SetPixelRed(q,intensity);
             if (scale != (Quantum *) NULL)
               SetPixelRed(q,scale[ConstrainPixel(image,(ssize_t)
-                intensity,max_value)]);
+                intensity,(size_t) max_value)]);
             SetPixelGreen(q,GetPixelRed(q));
             SetPixelBlue(q,GetPixelRed(q));
             q++;
@@ -565,11 +578,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             if (scale != (Quantum *) NULL)
               {
                 pixel.red=(MagickRealType) scale[ConstrainPixel(image,(ssize_t)
-                  pixel.red,max_value)];
+                  pixel.red,(size_t) max_value)];
                 pixel.green=(MagickRealType) scale[ConstrainPixel(image,
-                  (ssize_t) pixel.green,max_value)];
+                  (ssize_t) pixel.green,(size_t) max_value)];
                 pixel.blue=(MagickRealType) scale[ConstrainPixel(image,(ssize_t)
-                  pixel.blue,max_value)];
+                  pixel.blue,(size_t) max_value)];
               }
             SetPixelRed(q,pixel.red);
             SetPixelGreen(q,pixel.green);
@@ -595,7 +608,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert PBM raw image to pixel packets.
         */
-        SetImageColorspace(image,GRAYColorspace);
+        (void) SetImageColorspace(image,GRAYColorspace);
         quantum_type=GrayQuantum;
         if (image->storage_class == PseudoClass)
           quantum_type=IndexQuantum;
@@ -664,14 +677,10 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
       case '5':
       {
-        QuantumAny
-          range;
-
         /*
           Convert PGM raw image to pixel packets.
         */
-        SetImageColorspace(image,GRAYColorspace);
-        range=GetQuantumRange(image->depth);
+        (void) SetImageColorspace(image,GRAYColorspace);
         quantum_type=GrayQuantum;
         extent=(image->depth <= 8 ? 1 : 2)*image->columns;
         quantum_info=AcquireQuantumInfo(image_info,image);
@@ -737,7 +746,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
                   p=PushCharPixel(p,&pixel);
-                  SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                  SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                   SetPixelGreen(q,GetPixelRed(q));
                   SetPixelBlue(q,GetPixelRed(q));
                   q++;
@@ -751,7 +760,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
                   p=PushShortPixel(MSBEndian,p,&pixel);
-                  SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                  SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                   SetPixelGreen(q,GetPixelRed(q));
                   SetPixelBlue(q,GetPixelRed(q));
                   q++;
@@ -769,15 +778,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
       case '6':
       {
-        QuantumAny
-          range;
-
         /*
           Convert PNM raster image to pixel packets.
         */
         quantum_type=RGBQuantum;
         extent=3*(image->depth <= 8 ? 1 : 2)*image->columns;
-        range=GetQuantumRange(image->depth);
         quantum_info=AcquireQuantumInfo(image_info,image);
         if (quantum_info == (QuantumInfo *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -866,11 +871,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   for (x=0; x < (ssize_t) image->columns; x++)
                   {
                     p=PushCharPixel(p,&pixel);
-                    SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                     p=PushCharPixel(p,&pixel);
-                    SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                     p=PushCharPixel(p,&pixel);
-                    SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                     SetPixelOpacity(q,OpaqueOpacity);
                     q++;
                   }
@@ -883,11 +888,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   for (x=0; x < (ssize_t) image->columns; x++)
                   {
                     p=PushShortPixel(MSBEndian,p,&pixel);
-                    SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                     p=PushShortPixel(MSBEndian,p,&pixel);
-                    SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                     p=PushShortPixel(MSBEndian,p,&pixel);
-                    SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                    SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                     SetPixelOpacity(q,OpaqueOpacity);
                     q++;
                   }
@@ -906,16 +911,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         register IndexPacket
           *indexes;
 
-        QuantumAny
-          range;
-
         size_t
           channels;
 
         /*
           Convert PAM raster image to pixel packets.
         */
-        range=GetQuantumRange(image->depth);
         switch (quantum_type)
         {
           case GrayQuantum:
@@ -1008,15 +1009,14 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       SetPixelGreen(q,GetPixelRed(q));
                       SetPixelBlue(q,GetPixelRed(q));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1029,15 +1029,14 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       SetPixelGreen(q,GetPixelRed(q));
                       SetPixelBlue(q,GetPixelRed(q));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1055,20 +1054,19 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushCharPixel(p,&pixel);
-                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushCharPixel(p,&pixel);
-                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushCharPixel(p,&pixel);
                       SetPixelIndex(indexes+x,ScaleAnyToQuantum(pixel,
-                        range));
+                        max_value));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1081,20 +1079,19 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushShortPixel(MSBEndian,p,&pixel);
                       SetPixelIndex(indexes+x,ScaleAnyToQuantum(pixel,
-                        range));
+                        max_value));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1111,17 +1108,16 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushCharPixel(p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushCharPixel(p,&pixel);
-                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushCharPixel(p,&pixel);
-                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushCharPixel(p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1134,17 +1130,16 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelRed(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelRed(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelGreen(q,ScaleAnyToQuantum(pixel,max_value));
                       p=PushShortPixel(MSBEndian,p,&pixel);
-                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,range));
+                      SetPixelBlue(q,ScaleAnyToQuantum(pixel,max_value));
                       SetPixelOpacity(q,OpaqueOpacity);
                       if (image->matte != MagickFalse)
                         {
                           p=PushShortPixel(MSBEndian,p,&pixel);
-                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,
-                            range));
+                          SetPixelOpacity(q,ScaleAnyToQuantum(pixel,max_value));
                         }
                       q++;
                     }
@@ -1169,7 +1164,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Convert PFM raster image to pixel packets.
         */
         if (format == 'f')
-          SetImageColorspace(image,GRAYColorspace);
+          (void) SetImageColorspace(image,GRAYColorspace);
         quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
         image->endian=quantum_scale < 0.0 ? LSBEndian : MSBEndian;
         image->depth=32;
@@ -1326,12 +1321,14 @@ ModuleExport size_t RegisterPNMImage(void)
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Common 2-dimensional bitmap format");
+  entry->mime_type=ConstantString("image/x-portable-pixmap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PBM");
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable bitmap format (black and white)");
+  entry->mime_type=ConstantString("image/x-portable-bitmap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PFM");
@@ -1345,6 +1342,7 @@ ModuleExport size_t RegisterPNMImage(void)
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable graymap format (gray scale)");
+  entry->mime_type=ConstantString("image/x-portable-greymap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PNM");
@@ -1352,12 +1350,14 @@ ModuleExport size_t RegisterPNMImage(void)
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->magick=(IsImageFormatHandler *) IsPNM;
   entry->description=ConstantString("Portable anymap");
+  entry->mime_type=ConstantString("image/x-portable-pixmap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PPM");
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
   entry->description=ConstantString("Portable pixmap format (color)");
+  entry->mime_type=ConstantString("image/x-portable-pixmap");
   entry->module=ConstantString("PNM");
   (void) RegisterMagickInfo(entry);
   return(MagickImageCoderSignature);
@@ -1470,9 +1470,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
   scene=0;
   do
   {
+    QuantumAny
+      max_value;
+
     /*
       Write PNM file header.
     */
+    max_value=GetQuantumRange(image->depth);
     packet_size=3;
     quantum_type=RGBQuantum;
     (void) CopyMagickString(magick,image_info->magick,MaxTextExtent);
@@ -1549,9 +1553,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         for (p=value; *p != '\0'; p++)
         {
           (void) WriteBlobByte(image,(unsigned char) *p);
-          if ((*p == '\r') && (*(p+1) != '\0'))
-            (void) WriteBlobByte(image,'#');
-          if ((*p == '\n') && (*(p+1) != '\0'))
+          if ((*p == '\n') || (*p == '\r'))
             (void) WriteBlobByte(image,'#');
         }
         (void) WriteBlobByte(image,'\n');
@@ -1643,7 +1645,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            pixel=PixelIntensityToQuantum(image,p);
+            pixel=ClampToQuantum(GetPixelLuma(image,p));
             *q++=(unsigned char) (pixel >= (Quantum) (QuantumRange/2) ?
               '0' : '1');
             *q++=' ';
@@ -1696,7 +1698,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
             break;
           for (x=0; x < (ssize_t) image->columns; x++)
           {
-            index=PixelIntensityToQuantum(image,p);
+            index=ClampToQuantum(GetPixelLuma(image,p));
             if (image->depth <= 8)
               count=(ssize_t) FormatLocaleString(buffer,MaxTextExtent,"%u ",
                 ScaleQuantumToChar(index));
@@ -1830,9 +1832,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       }
       case '5':
       {
-        QuantumAny
-          range;
-
         /*
           Convert image to a PGM image.
         */
@@ -1847,7 +1846,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         quantum_info->min_is_white=MagickTrue;
         pixels=GetQuantumPixels(quantum_info);
         extent=GetQuantumExtent(image,quantum_info,GrayQuantum);
-        range=GetQuantumRange(image->depth);
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
@@ -1869,14 +1867,14 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
                   if (IsGrayPixel(p) == MagickFalse)
-                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(image,p),
-                      range);
+                    pixel=ScaleQuantumToAny(ClampToQuantum(
+                      GetPixelLuma(image,p)),max_value);
                   else
                     {
                       if (image->depth == 8)
                         pixel=ScaleQuantumToChar(GetPixelRed(p));
                       else
-                        pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                        pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                     }
                   q=PopCharPixel((unsigned char) pixel,q);
                   p++;
@@ -1885,14 +1883,14 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
                   if (IsGrayPixel(p) == MagickFalse)
-                    pixel=ScaleQuantumToAny(PixelIntensityToQuantum(image,p),
-                      range);
+                    pixel=ScaleQuantumToAny(ClampToQuantum(
+                      GetPixelLuma(image,p)),max_value);
                   else
                     {
                       if (image->depth == 16)
                         pixel=ScaleQuantumToShort(GetPixelRed(p));
                       else
-                        pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                        pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                     }
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                   p++;
@@ -1915,9 +1913,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       }
       case '6':
       {
-        QuantumAny
-          range;
-
         /*
           Convert image to a PNM image.
         */
@@ -1934,7 +1929,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         (void) SetQuantumEndian(image,quantum_info,MSBEndian);
         pixels=GetQuantumPixels(quantum_info);
         extent=GetQuantumExtent(image,quantum_info,quantum_type);
-        range=GetQuantumRange(image->depth);
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const PixelPacket
@@ -1955,22 +1949,22 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
               if (image->depth <= 8)
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                   q=PopCharPixel((unsigned char) pixel,q);
-                  pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                   q=PopCharPixel((unsigned char) pixel,q);
-                  pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                   q=PopCharPixel((unsigned char) pixel,q);
                   p++;
                 }
               else
                 for (x=0; x < (ssize_t) image->columns; x++)
                 {
-                  pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                  pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                  pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                  pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                   q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                   p++;
                 }
@@ -1992,9 +1986,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
       }
       case '7':
       {
-        QuantumAny
-          range;
-
         /*
           Convert image to a PAM.
         */
@@ -2002,7 +1993,6 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           image->depth=16;
         quantum_info=AcquireQuantumInfo((const ImageInfo *) NULL,image);
         pixels=GetQuantumPixels(quantum_info);
-        range=GetQuantumRange(image->depth);
         for (y=0; y < (ssize_t) image->rows; y++)
         {
           register const IndexPacket
@@ -2032,13 +2022,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(image,p),
-                        range);
+                      pixel=ScaleQuantumToAny(ClampToQuantum(
+                        GetPixelLuma(image,p)),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=(unsigned char) ScaleQuantumToAny(
-                            GetPixelOpacity(p),range);
+                            GetPixelOpacity(p),max_value);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2046,13 +2036,13 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(image,p),
-                        range);
+                      pixel=ScaleQuantumToAny(ClampToQuantum(
+                        GetPixelLuma(image,p)),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=(unsigned char) ScaleQuantumToAny(
-                            GetPixelOpacity(p),range);
+                            GetPixelOpacity(p),max_value);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
@@ -2065,19 +2055,19 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(
-                        GetPixelIndex(indexes+x),range);
+                      pixel=ScaleQuantumToAny(GetPixelIndex(indexes+x),
+                        max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            GetPixelOpacity(p)),range);
+                            GetPixelOpacity(p)),max_value);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2085,19 +2075,19 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(
-                        GetPixelIndex(indexes+x),range);
+                      pixel=ScaleQuantumToAny(GetPixelIndex(indexes+x),
+                        max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            GetPixelOpacity(p)),range);
+                            GetPixelOpacity(p)),max_value);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
@@ -2109,16 +2099,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            GetPixelOpacity(p)),range);
+                            GetPixelOpacity(p)),max_value);
                           q=PopCharPixel((unsigned char) pixel,q);
                         }
                       p++;
@@ -2126,16 +2116,16 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (ssize_t) image->columns; x++)
                     {
-                      pixel=ScaleQuantumToAny(GetPixelRed(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelRed(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelGreen(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelGreen(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
-                      pixel=ScaleQuantumToAny(GetPixelBlue(p),range);
+                      pixel=ScaleQuantumToAny(GetPixelBlue(p),max_value);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
                           pixel=ScaleQuantumToAny((Quantum) (QuantumRange-
-                            GetPixelOpacity(p)),range);
+                            GetPixelOpacity(p)),max_value);
                           q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                         }
                       p++;
