@@ -582,7 +582,7 @@ static MagickBooleanType ReadPSDLayer(Image *image,const size_t channels,
       for (y=0; y < (ssize_t) image->rows; y++)
         if ((MagickOffsetType) length < offsets[y])
           length=(size_t) offsets[y];
-      compact_pixels=(unsigned char *) AcquireQuantumMemory(length,
+      compact_pixels=(unsigned char *) AcquireQuantumMemory(length+256,
         sizeof(*pixels));
       if (compact_pixels == (unsigned char *) NULL)
         ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -851,7 +851,8 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (psd_info.mode == DuotoneMode))
     {
       psd_info.color_channels=1;
-      if (AcquireImageColormap(image,256) == MagickFalse)
+      status=AcquireImageColormap(image,psd_info.depth != 16 ? 256 : 65536);
+      if (status == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       if (image->debug != MagickFalse)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),
@@ -926,6 +927,14 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
       (void) ParseImageResourceBlocks(image,blocks,(size_t) length);
       blocks=(unsigned char *) RelinquishMagickMemory(blocks);
     }
+   /*
+     If we are only "pinging" the image, then we're done - so return.
+   */
+  if (image_info->ping != MagickFalse)
+    {
+      (void) CloseBlob(image);
+      return(GetFirstImageInList(image));
+    }
   /*
     Layer and mask block.
   */
