@@ -229,8 +229,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->columns=tga_info.width;
   image->rows=tga_info.height;
   alpha_bits=(tga_info.attributes & 0x0FU);
-  image->matte=(alpha_bits > 0) || (tga_info.bits_per_pixel == 32) ?
-    MagickTrue : MagickFalse;
+  image->matte=(alpha_bits > 0) || (tga_info.bits_per_pixel == 32) ||
+    (tga_info.colormap_size == 32) ?  MagickTrue : MagickFalse;
   if ((tga_info.image_type != TGAColormap) &&
       (tga_info.image_type != TGARLEColormap))
     image->depth=(size_t) ((tga_info.bits_per_pixel <= 8) ? 8 :
@@ -332,7 +332,6 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
             break;
           }
           case 24:
-          case 32:
           {
             /*
               8 bits each of blue, green and red.
@@ -342,6 +341,18 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
             pixel.red=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             break;
           }
+          case 32:
+          {
+            /*
+              8 bits each of blue, green, red, and alpha.
+            */
+            pixel.blue=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
+            pixel.green=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
+            pixel.red=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
+            pixel.opacity=(Quantum) (QuantumRange-ScaleCharToQuantum(
+              (unsigned char) ReadBlobByte(image)));
+            break;
+          }
         }
         image->colormap[i]=pixel;
       }
@@ -809,15 +820,15 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
         *q++=(unsigned char) GetPixelIndex(indexes+x);
       else
         if (targa_info.image_type == TargaMonochrome)
-          *q++=(unsigned char) ScaleQuantumToChar(PixelIntensityToQuantum(image,p));
+          *q++=(unsigned char) ScaleQuantumToChar(ClampToQuantum(
+            GetPixelLuma(image,p)));
         else
           {
             *q++=ScaleQuantumToChar(GetPixelBlue(p));
             *q++=ScaleQuantumToChar(GetPixelGreen(p));
             *q++=ScaleQuantumToChar(GetPixelRed(p));
             if (image->matte != MagickFalse)
-              *q++=(unsigned char) ScaleQuantumToChar(
-                GetPixelAlpha(p));
+              *q++=(unsigned char) ScaleQuantumToChar(GetPixelAlpha(p));
             if (image->colorspace == CMYKColorspace)
               *q++=ScaleQuantumToChar(GetPixelIndex(indexes+x));
           }
