@@ -18,7 +18,7 @@
 %                                March 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,6 +52,7 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/module.h"
+#include "magick/pixel-accessor.h"
 #include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/resource_.h"
@@ -59,7 +60,7 @@
 #include "magick/utility.h"
 #if defined(MAGICKCORE_XML_DELEGATE)
 #  if defined(MAGICKCORE_WINDOWS_SUPPORT)
-#    if defined(__MINGW32__)
+#    if defined(__MINGW32__) || defined(__MINGW64__)
 #      define _MSC_VER
 #    else
 #      include <win32config.h>
@@ -153,12 +154,9 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     file=fdopen(unique_file,"wb");
   if ((unique_file == -1) || (file == (FILE *) NULL))
     {
-      read_info=DestroyImageInfo(read_info);
-      (void) CopyMagickString(image->filename,read_info->filename,
-        MaxTextExtent);
       ThrowFileException(exception,FileOpenError,"UnableToCreateTemporaryFile",
-        image->filename);
-      image=DestroyImageList(image);
+        read_info->filename);
+      read_info=DestroyImageInfo(read_info);
       return((Image *) NULL);
     }
   (void) CopyMagickString(filename,image_info->magick,MaxTextExtent);
@@ -220,7 +218,23 @@ static Image *ReadURLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
 #endif
   (void) fclose(file);
-  *read_info->magick='\0';
+  {
+    ExceptionInfo
+      *sans;
+
+    ImageInfo
+      *clone_info;
+
+    /*
+      Guess image format from URL.
+    */
+    clone_info=CloneImageInfo(image_info);
+    sans=AcquireExceptionInfo();
+    (void) SetImageInfo(clone_info,0,sans);
+    (void) CopyMagickString(read_info->magick,clone_info->magick,MaxTextExtent);
+    clone_info=DestroyImageInfo(clone_info);
+    sans=DestroyExceptionInfo(sans);
+  }
   image=ReadImage(read_info,exception);
   if (unique_file != -1)
     (void) RelinquishUniqueFileResource(read_info->filename);
