@@ -323,7 +323,6 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if ((count != 4) || (width > 10) || (image->columns == 0) ||
       (image->rows == 0) || (image->colors == 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  image->depth=16;
   /*
     Remove unquoted characters.
   */
@@ -351,9 +350,13 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read image colormap.
   */
+  image->depth=1;
   next=NextXPMLine(xpm_buffer);
   for (j=0; (j < (ssize_t) image->colors) && (next != (char*) NULL); j++)
   {
+    MagickPixelPacket
+      pixel;
+
     p=next;
     next=NextXPMLine(p);
     (void) CopyXPMColor(key,p,MagickMin((size_t) width,MaxTextExtent));
@@ -386,6 +389,9 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       exception);
     if (status == MagickFalse)
       break;
+    status=QueryMagickColorCompliance(target,XPMCompliance,&pixel,exception);
+    if (image->depth < pixel.depth)
+      image->depth=pixel.depth;
   }
   if (j < (ssize_t) image->colors)
     ThrowReaderException(CorruptImageError,"CorruptImage");
