@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@
 extern "C" {
 #endif
 
-#include <magick/image.h>
-#include <magick/exception.h>
+#include "magick/image.h"
+#include "magick/exception.h"
 
 extern MagickExport ImageType
   GetImageType(const Image *,ExceptionInfo *);
@@ -33,7 +33,8 @@ extern MagickExport MagickBooleanType
   IsMonochromeImage(const Image *,ExceptionInfo *),
   IsOpaqueImage(const Image *,ExceptionInfo *),
   SetImageChannelDepth(Image *,const ChannelType,const size_t),
-  SetImageDepth(Image *,const size_t);
+  SetImageDepth(Image *,const size_t),
+  SetImageType(Image *,const ImageType);
 
 extern MagickExport RectangleInfo
   GetImageBoundingBox(const Image *,ExceptionInfo *exception);
