@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -25,7 +25,7 @@ extern "C" {
 #include "magick/image.h"
 #include "magick/stream.h"
 
-#define MagickMaxBufferExtent  0x3c005L
+#define MagickMaxBufferExtent  (32*8192-2)
 
 typedef enum
 {
