@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -50,7 +50,9 @@ typedef struct _CacheView
   CacheView;
 
 extern MagickExport CacheView
+  *AcquireAuthenticCacheView(const Image *,ExceptionInfo *),
   *AcquireCacheView(const Image *),
+  *AcquireVirtualCacheView(const Image *,ExceptionInfo *),
   *CloneCacheView(const CacheView *),
   *DestroyCacheView(CacheView *);
 
