@@ -136,8 +136,8 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
       combine_image=DestroyImage(combine_image);
       return((Image *) NULL);
     }
-  if (IsGrayColorspace(image->colorspace) != MagickFalse)
-    (void) SetImageColorspace(combine_image,RGBColorspace);
+  if (IssRGBCompatibleColorspace(image->colorspace) == MagickFalse)
+    (void) SetImageColorspace(combine_image,sRGBColorspace);
   if ((channel & OpacityChannel) != 0)
     combine_image->matte=MagickTrue;
   (void) SetImageBackgroundColor(combine_image);
@@ -186,7 +186,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
         q=pixels;
         for (x=0; x < (ssize_t) combine_image->columns; x++)
         {
-          SetPixelRed(q,PixelIntensityToQuantum(image,p));
+          SetPixelRed(q,ClampToQuantum(GetPixelIntensity(image,p)));
           p++;
           q++;
         }
@@ -202,7 +202,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
         q=pixels;
         for (x=0; x < (ssize_t) combine_image->columns; x++)
         {
-          SetPixelGreen(q,PixelIntensityToQuantum(image,p));
+          SetPixelGreen(q,ClampToQuantum(GetPixelIntensity(image,p)));
           p++;
           q++;
         }
@@ -218,7 +218,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
         q=pixels;
         for (x=0; x < (ssize_t) combine_image->columns; x++)
         {
-          SetPixelBlue(q,PixelIntensityToQuantum(image,p));
+          SetPixelBlue(q,ClampToQuantum(GetPixelIntensity(image,p)));
           p++;
           q++;
         }
@@ -234,7 +234,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
         q=pixels;
         for (x=0; x < (ssize_t) combine_image->columns; x++)
         {
-          SetPixelAlpha(q,PixelIntensityToQuantum(image,p));
+          SetPixelAlpha(q,ClampToQuantum(GetPixelIntensity(image,p)));
           p++;
           q++;
         }
@@ -254,7 +254,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
         indexes=GetCacheViewAuthenticIndexQueue(combine_view);
         for (x=0; x < (ssize_t) combine_image->columns; x++)
         {
-          SetPixelIndex(indexes+x,PixelIntensityToQuantum(image,p));
+          SetPixelIndex(indexes+x,ClampToQuantum(GetPixelIntensity(image,p)));
           p++;
         }
         image_view=DestroyCacheView(image_view);
@@ -275,7 +275,7 @@ MagickExport Image *CombineImages(const Image *image,const ChannelType channel,
   }
   combine_view=DestroyCacheView(combine_view);
   if (IsGrayColorspace(combine_image->colorspace) != MagickFalse)
-    (void) TransformImageColorspace(combine_image,RGBColorspace);
+    (void) TransformImageColorspace(combine_image,sRGBColorspace);
   if (status == MagickFalse)
     combine_image=DestroyImage(combine_image);
   return(combine_image);
@@ -474,7 +474,7 @@ MagickExport MagickBooleanType SeparateImageChannel(Image *image,
       {
         for (x=0; x < (ssize_t) image->columns; x++)
         {
-          SetPixelAlpha(q,PixelIntensityToQuantum(image,q));
+          SetPixelAlpha(q,ClampToQuantum(GetPixelIntensity(image,q)));
           q++;
         }
         break;
@@ -500,10 +500,7 @@ MagickExport MagickBooleanType SeparateImageChannel(Image *image,
   image_view=DestroyCacheView(image_view);
   if (channel != GrayChannels)
     image->matte=MagickFalse;
-  if (IssRGBColorspace(image->colorspace) == MagickFalse)
-    (void) SetImageColorspace(image,GRAYColorspace);
-  else
-    (void) TransformImageColorspace(image,GRAYColorspace);
+  (void) SetImageColorspace(image,GRAYColorspace);
   return(status);
 }
 
