@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -22,10 +22,10 @@
 extern "C" {
 #endif
 
-#include <magick/image.h>
-#include <magick/color.h>
-#include <magick/exception-private.h>
-#include <magick/pixel-accessor.h>
+#include "magick/image.h"
+#include "magick/color.h"
+#include "magick/exception-private.h"
+#include "magick/pixel-accessor.h"
 
 static inline MagickBooleanType IsColorEqual(const PixelPacket *p,
   const PixelPacket *q)
@@ -87,23 +87,22 @@ static inline MagickBooleanType IsMagickGray(const MagickPixelPacket *pixel)
 static inline MagickRealType MagickPixelIntensity(
   const MagickPixelPacket *pixel)
 {
-  MagickRealType
-    blue,
-    green,
-    red;
-
   if (pixel->colorspace == GRAYColorspace)
     return(pixel->red);
-  if (pixel->colorspace != sRGBColorspace)
-    return(0.298839*pixel->red+0.586811*pixel->green+0.114350*pixel->blue);
-  red=InversesRGBCompandor(pixel->red);
-  green=InversesRGBCompandor(pixel->green);
-  blue=InversesRGBCompandor(pixel->blue);
-  return(0.298839*red+0.586811*green+0.114350*blue);
+  return(0.212656*pixel->red+0.715158*pixel->green+0.072186*pixel->blue);
 }
 
 static inline Quantum MagickPixelIntensityToQuantum(
   const MagickPixelPacket *pixel)
+{
+  if (pixel->colorspace == GRAYColorspace)
+    return(ClampToQuantum(pixel->red));
+  return(ClampToQuantum(0.212656*pixel->red+0.715158*pixel->green+
+    0.072186*pixel->blue));
+}
+
+static inline MagickRealType MagickPixelLuma(
+  const MagickPixelPacket *pixel)
 {
   MagickRealType
     blue,
@@ -111,14 +110,13 @@ static inline Quantum MagickPixelIntensityToQuantum(
     red;
 
   if (pixel->colorspace == GRAYColorspace)
-    return(ClampToQuantum(pixel->red));
-  if (pixel->colorspace != sRGBColorspace)
-    return(ClampToQuantum(0.298839*pixel->red+0.586811*pixel->green+
-      0.114350*pixel->blue));
-  red=InversesRGBCompandor(pixel->red);
-  green=InversesRGBCompandor(pixel->green);
-  blue=InversesRGBCompandor(pixel->blue);
-  return(ClampToQuantum(0.298839*red+0.586811*green+0.114350*blue));
+    return(pixel->red);
+  if (pixel->colorspace == sRGBColorspace)
+    return(0.212656*pixel->red+0.715158*pixel->green+0.072186*pixel->blue);
+  red=EncodePixelGamma(pixel->red);
+  green=EncodePixelGamma(pixel->green);
+  blue=EncodePixelGamma(pixel->blue);
+  return(0.212656*red+0.715158*green+0.072186*blue);
 }
 
 static inline MagickRealType MagickPixelLuminance(
@@ -132,11 +130,11 @@ static inline MagickRealType MagickPixelLuminance(
   if (pixel->colorspace == GRAYColorspace)
     return(pixel->red);
   if (pixel->colorspace != sRGBColorspace)
-    return(0.21267*pixel->red+0.71516*pixel->green+0.07217*pixel->blue);
-  red=InversesRGBCompandor(pixel->red);
-  green=InversesRGBCompandor(pixel->green);
-  blue=InversesRGBCompandor(pixel->blue);
-  return(0.21267*red+0.71516*green+0.07217*blue);
+    return(0.212656*pixel->red+0.715158*pixel->green+0.072186*pixel->blue);
+  red=DecodePixelGamma(pixel->red);
+  green=DecodePixelGamma(pixel->green);
+  blue=DecodePixelGamma(pixel->blue);
+  return(0.212656*red+0.715158*green+0.072186*blue);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
