@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -22,8 +22,8 @@
 extern "C" {
 #endif
 
-#include <magick/pixel.h>
-#include <magick/exception.h>
+#include "magick/pixel.h"
+#include "magick/exception.h"
 
 typedef enum
 {
@@ -55,7 +55,7 @@ typedef struct _ColorInfo
     *previous,
     *next;  /* deprecated, use GetColorInfoList() */
 
-  unsigned long
+  size_t
     signature;
 } ColorInfo;
 
@@ -68,25 +68,30 @@ typedef struct _ErrorInfo
 } ErrorInfo;
 
 extern MagickExport char
-  **GetColorList(const char *,unsigned long *,ExceptionInfo *);
+  **GetColorList(const char *,size_t *,ExceptionInfo *);
 
 extern MagickExport const ColorInfo
   *GetColorInfo(const char *,ExceptionInfo *),
-  **GetColorInfoList(const char *,unsigned long *,ExceptionInfo *);
+  **GetColorInfoList(const char *,size_t *,ExceptionInfo *);
 
 extern MagickExport MagickBooleanType
   ColorComponentGenesis(void),
   IsColorSimilar(const Image *,const PixelPacket *,const PixelPacket *),
   IsGrayImage(const Image *,ExceptionInfo *),
-  IsImageSimilar(const Image *,const Image *,long *x,long *y,ExceptionInfo *),
+  IsImageSimilar(const Image *,const Image *,ssize_t *x,ssize_t *y,
+    ExceptionInfo *),
   IsMagickColorSimilar(const MagickPixelPacket *,const MagickPixelPacket *),
   IsMonochromeImage(const Image *,ExceptionInfo *),
   IsOpacitySimilar(const Image *,const PixelPacket *,const PixelPacket *),
   IsOpaqueImage(const Image *,ExceptionInfo *),
   ListColorInfo(FILE *,ExceptionInfo *),
+  QueryColorCompliance(const char *,const ComplianceType,PixelPacket *,
+    ExceptionInfo *),
   QueryColorDatabase(const char *,PixelPacket *,ExceptionInfo *),
   QueryColorname(const Image *,const PixelPacket *,const ComplianceType,char *,
     ExceptionInfo *),
+  QueryMagickColorCompliance(const char *,const ComplianceType,
+    MagickPixelPacket *,ExceptionInfo *),
   QueryMagickColor(const char *,MagickPixelPacket *,ExceptionInfo *),
   QueryMagickColorname(const Image *,const MagickPixelPacket *,
     const ComplianceType,char *,ExceptionInfo *);
