@@ -62,6 +62,7 @@
 #include "magick/monitor-private.h"
 #include "magick/option.h"
 #include "magick/pixel-private.h"
+#include "magick/property.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
 #include "magick/string-private.h"
@@ -994,6 +995,17 @@ static MagickBooleanType GetNormalizedCrossCorrelationDistortion(
   */
   image_statistics=GetImageChannelStatistics(image,exception);
   reconstruct_statistics=GetImageChannelStatistics(reconstruct_image,exception);
+  if ((image_statistics == (ChannelStatistics *) NULL) ||
+      (reconstruct_statistics == (ChannelStatistics *) NULL))
+    {
+      if (image_statistics != (ChannelStatistics *) NULL)
+        image_statistics=(ChannelStatistics *) RelinquishMagickMemory(
+          image_statistics);
+      if (reconstruct_statistics != (ChannelStatistics *) NULL)
+        reconstruct_statistics=(ChannelStatistics *) RelinquishMagickMemory(
+          reconstruct_statistics);
+      return(MagickFalse);
+    }
   status=MagickTrue;
   progress=0;
   for (i=0; i <= (ssize_t) CompositeChannels; i++)
@@ -1393,6 +1405,8 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
   }
   *distortion=channel_distortion[CompositeChannels];
   channel_distortion=(double *) RelinquishMagickMemory(channel_distortion);
+  (void) FormatImageProperty(image,"distortion","%.*g",GetMagickPrecision(),
+    *distortion);
   return(status);
 }
 
@@ -1846,7 +1860,9 @@ MagickExport Image *SimilarityMetricImage(Image *image,const Image *reference,
 
     if (status == MagickFalse)
       continue;
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
     #pragma omp flush(similarity_metric)
+#endif
     if (*similarity_metric <= similarity_threshold)
       continue;
     q=GetCacheViewAuthenticPixels(similarity_view,0,y,similarity_image->columns,
@@ -1858,7 +1874,9 @@ MagickExport Image *SimilarityMetricImage(Image *image,const Image *reference,
       }
     for (x=0; x < (ssize_t) (image->columns-reference->columns+1); x++)
     {
+#if defined(MAGICKCORE_OPENMP_SUPPORT)
       #pragma omp flush(similarity_metric)
+#endif
       if (*similarity_metric <= similarity_threshold)
         break;
       similarity=GetSimilarityMetric(image,reference,metric,x,y,exception);
