@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -93,10 +93,14 @@ typedef enum
   LinearBurnCompositeOp,
   MathematicsCompositeOp,
   DivideSrcCompositeOp,
-  MinusSrcCompositeOp
+  MinusSrcCompositeOp,
+  DarkenIntensityCompositeOp,
+  LightenIntensityCompositeOp
 } CompositeOperator;
 
-/* Depreciated (renamed) Method Names for backward compatibility */
+/* Depreciated (renamed) Method Names for backward compatibility
+ * However the CompositeOp value has not changed, just renamed.
+ */
 #define AddCompositeOp       ModulusAddCompositeOp
 #define SubtractCompositeOp  ModulusSubtractCompositeOp
 #define MinusCompositeOp     MinusDstCompositeOp
