@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -46,6 +46,10 @@ extern "C" {
 
 #define Downscale(quantum)  ScaleQuantumToChar(quantum)
 #define LABColorspace LabColorspace
+#define CompressPixelGamma(pixel)  DecodePixelGamma(pixel)
+#define DecodesRGBGamma(pixel)  DecodePixelGamma(pixel)
+#define EncodesRGBGamma(pixel)  EncodePixelGamma(pixel)
+#define ExpandPixelGamma(pixel)  EncodePixelGamma(pixel)
 #define Intensity(color)  PixelIntensityToQuantum(color)
 #define LiberateUniqueFileResource(resource) \
   RelinquishUniqueFileResource(resource)
@@ -354,6 +358,12 @@ static inline double MagickEpsilonReciprocal(const double x)
   return(sign/MagickEpsilon);
 }
 
+static inline Quantum PixelIntensityToQuantum(const Image *restrict image,
+  const PixelPacket *restrict pixel)
+{
+  return(ClampToQuantum(GetPixelIntensity(image,pixel)));
+}
+
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
