@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -41,9 +41,6 @@ static inline MagickBooleanType GetFillColor(const DrawInfo *draw_info,
       *pixel=draw_info->fill;
       return(MagickTrue);
     }
-#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP >= 200203)
-  #pragma omp critical
-#endif
   status=GetOneVirtualMethodPixel(pattern,TileVirtualPixelMethod,
     x+pattern->tile_offset.x,y+pattern->tile_offset.y,pixel,
     &pattern->exception);
@@ -67,9 +64,6 @@ static inline MagickBooleanType GetStrokeColor(const DrawInfo *draw_info,
       *pixel=draw_info->stroke;
       return(MagickTrue);
     }
-#if defined(MAGICKCORE_OPENMP_SUPPORT) && (_OPENMP >= 200203)
-  #pragma omp critical
-#endif
   status=GetOneVirtualMethodPixel(pattern,TileVirtualPixelMethod,
     x+pattern->tile_offset.x,y+pattern->tile_offset.y,pixel,
     &pattern->exception);
