@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2011 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@
 extern "C" {
 #endif
 
-#include <magick/morphology.h>
+#include "magick/morphology.h"
 
 typedef enum
 {
@@ -58,19 +58,6 @@ typedef enum
   JPEGPreview
 } PreviewType;
 
-typedef enum
-{
-  UndefinedStatistic,
-  GradientStatistic,
-  MaximumStatistic,
-  MeanStatistic,
-  MedianStatistic,
-  MinimumStatistic,
-  ModeStatistic,
-  NonpeakStatistic,
-  StandardDeviationStatistic
-} StatisticType;
-
 extern MagickExport Image
   *AdaptiveBlurImage(const Image *,const double,const double,ExceptionInfo *),
   *AdaptiveBlurImageChannel(const Image *,const ChannelType,const double,
@@ -112,10 +99,6 @@ extern MagickExport Image
   *SharpenImageChannel(const Image *,const ChannelType,const double,
     const double,ExceptionInfo *),
   *SpreadImage(const Image *,const double,ExceptionInfo *),
-  *StatisticImage(const Image *,const StatisticType,const size_t,const size_t,
-    ExceptionInfo *),
-  *StatisticImageChannel(const Image *,const ChannelType,const StatisticType,
-    const size_t,const size_t,ExceptionInfo *),
   *UnsharpMaskImage(const Image *,const double,const double,const double,
     const double,ExceptionInfo *),
   *UnsharpMaskImageChannel(const Image *,const ChannelType,const double,
