@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -23,6 +23,7 @@ extern "C" {
 #endif
 
 #include "magick/log.h"
+#include "magick/magick.h"
 #include "magick/string_.h"
 
 #define ThrowBinaryException(severity,tag,context) \
@@ -47,7 +48,8 @@ extern "C" {
   message=DestroyString(message); \
   CatchException(&exception); \
   (void) DestroyExceptionInfo(&exception); \
-  _exit(1); \
+  MagickCoreTerminus(); \
+  _exit((int) (severity-FatalErrorException)+1); \
 }
 #define ThrowFileException(exception,severity,tag,context) \
 { \
