@@ -230,8 +230,7 @@ MagickExport MagickBooleanType DuplexTransferImageViewIterator(
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   size_t
-    height,
-    width;
+    height;
 #endif
 
   ssize_t
@@ -250,9 +249,8 @@ MagickExport MagickBooleanType DuplexTransferImageViewIterator(
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   height=(size_t) (source->extent.height-source->extent.y);
-  width=(size_t) (source->extent.width-source->extent.x);
   #pragma omp parallel for schedule(static,4) shared(progress,status) \
-    dynamic_number_threads(source_image,width,height,1)
+    magick_threads(source_image,destination_image,height,1)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -549,8 +547,7 @@ MagickExport MagickBooleanType GetImageViewIterator(ImageView *source,
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   size_t
-    height,
-    width;
+    height;
 #endif
 
   ssize_t
@@ -565,9 +562,8 @@ MagickExport MagickBooleanType GetImageViewIterator(ImageView *source,
   progress=0;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   height=(size_t) (source->extent.height-source->extent.y);
-  width=(size_t) (source->extent.width-source->extent.x);
   #pragma omp parallel for schedule(static,4) shared(progress,status) \
-    dynamic_number_threads(source_image,width,height,1)
+    magick_threads(source_image,source_image,height,1)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -895,8 +891,7 @@ MagickExport MagickBooleanType SetImageViewIterator(ImageView *destination,
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   size_t
-    height,
-    width;
+    height;
 #endif
 
   ssize_t
@@ -913,12 +908,11 @@ MagickExport MagickBooleanType SetImageViewIterator(ImageView *destination,
   progress=0;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   height=(size_t) (destination->extent.height-destination->extent.y);
-  width=(size_t) (destination->extent.width-destination->extent.x);
 #endif
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   #pragma omp parallel for schedule(static,4) shared(progress,status) \
-    dynamic_number_threads(destination_image,width,height,1)
+    magick_threads(destination_image,destination_image,height,1)
 #endif
   for (y=destination->extent.y; y < (ssize_t) destination->extent.height; y++)
   {
@@ -1069,8 +1063,7 @@ MagickExport MagickBooleanType TransferImageViewIterator(ImageView *source,
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   size_t
-    height,
-    width;
+    height;
 #endif
 
   ssize_t
@@ -1089,9 +1082,8 @@ MagickExport MagickBooleanType TransferImageViewIterator(ImageView *source,
   exception=destination->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   height=(size_t) (source->extent.height-source->extent.y);
-  width=(size_t) (source->extent.width-source->extent.x);
   #pragma omp parallel for schedule(static,4) shared(progress,status) \
-    dynamic_number_threads(source_image,width,height,1)
+    magick_threads(source_image,destination_image,height,1)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
@@ -1209,8 +1201,7 @@ MagickExport MagickBooleanType UpdateImageViewIterator(ImageView *source,
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   size_t
-    height,
-    width;
+    height;
 #endif
 
   ssize_t
@@ -1228,9 +1219,8 @@ MagickExport MagickBooleanType UpdateImageViewIterator(ImageView *source,
   exception=source->exception;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
   height=(size_t) (source->extent.height-source->extent.y);
-  width=(size_t) (source->extent.width-source->extent.x);
   #pragma omp parallel for schedule(static,4) shared(progress,status) \
-    dynamic_number_threads(source_image,width,height,1)
+    magick_threads(source_image,source_image,height,1)
 #endif
   for (y=source->extent.y; y < (ssize_t) source->extent.height; y++)
   {
