@@ -125,7 +125,6 @@ struct _LogInfo
 
   MagickBooleanType
     append,
-    exempt,
     stealth;
 
   TimerInfo
@@ -700,7 +699,13 @@ MagickExport MagickBooleanType ListLogInfo(FILE *file,ExceptionInfo *exception)
 */
 MagickExport MagickBooleanType LogComponentGenesis(void)
 {
+  ExceptionInfo
+    *exception;
+
   AcquireSemaphoreInfo(&log_semaphore);
+  exception=AcquireExceptionInfo();
+  (void) GetLogInfo("*",exception);
+  exception=DestroyExceptionInfo(exception);
   return(MagickTrue);
 }
 
@@ -735,15 +740,12 @@ static void *DestroyLogElement(void *log_info)
       (void) fclose(p->file);
       p->file=(FILE *) NULL;
     }
-  if (p->exempt == MagickFalse)
-    {
-      if (p->format != (char *) NULL)
-        p->format=DestroyString(p->format);
-      if (p->path != (char *) NULL)
-        p->path=DestroyString(p->path);
-      if (p->filename != (char *) NULL)
-        p->filename=DestroyString(p->filename);
-    }
+  if (p->format != (char *) NULL)
+    p->format=DestroyString(p->format);
+  if (p->path != (char *) NULL)
+    p->path=DestroyString(p->path);
+  if (p->filename != (char *) NULL)
+    p->filename=DestroyString(p->filename);
   p=(LogInfo *) RelinquishMagickMemory(p);
   return((void *) NULL);
 }
@@ -1172,6 +1174,7 @@ MagickBooleanType LogMagickEventList(const LogEventType type,const char *module,
     {
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
       OutputDebugString(text);
+      OutputDebugString("\n");
 #endif
     }
   if ((log_info->handler_mask & EventHandler) != 0)
@@ -1378,7 +1381,7 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
                   xml=FileToString(path,~0,exception);
                   if (xml != (char *) NULL)
                     {
-                      status|=LoadLogList(xml,path,depth+1,exception);
+                      status&=LoadLogList(xml,path,depth+1,exception);
                       xml=DestroyString(xml);
                     }
                 }
@@ -1397,7 +1400,6 @@ static MagickBooleanType LoadLogList(const char *xml,const char *filename,
         (void) ResetMagickMemory(log_info,0,sizeof(*log_info));
         log_info->path=ConstantString(filename);
         GetTimerInfo((TimerInfo *) &log_info->timer);
-        log_info->exempt=MagickFalse;
         log_info->signature=MagickSignature;
         continue;
       }
@@ -1560,7 +1562,7 @@ static MagickBooleanType LoadLogLists(const char *filename,
   option=(const StringInfo *) GetNextValueInLinkedList(options);
   while (option != (const StringInfo *) NULL)
   {
-    status|=LoadLogList((const char *) GetStringInfoDatum(option),
+    status&=LoadLogList((const char *) GetStringInfoDatum(option),
       GetStringInfoPath(option),0,exception);
     option=(const StringInfo *) GetNextValueInLinkedList(options);
   }
@@ -1585,15 +1587,14 @@ static MagickBooleanType LoadLogLists(const char *filename,
         continue;
       }
     (void) ResetMagickMemory(log_info,0,sizeof(*log_info));
-    log_info->path=(char *) "[built-in]";
+    log_info->path=ConstantString("[built-in]");
     GetTimerInfo((TimerInfo *) &log_info->timer);
     log_info->event_mask=p->event_mask;
     log_info->handler_mask=p->handler_mask;
     log_info->filename=ConstantString(p->filename);
     log_info->format=ConstantString(p->format);
-    log_info->exempt=MagickTrue;
     log_info->signature=MagickSignature;
-    status|=AppendValueToLinkedList(log_list,log_info);
+    status&=AppendValueToLinkedList(log_list,log_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",log_info->name);
