@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2010 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -43,7 +43,7 @@ typedef struct _MontageInfo
   double
     pointsize;
 
-  unsigned long
+  size_t
     border_width;
 
   MagickBooleanType
@@ -65,7 +65,7 @@ typedef struct _MontageInfo
   MagickBooleanType
     debug;
 
-  unsigned long
+  size_t
     signature;
 } MontageInfo;
 
