@@ -17,7 +17,7 @@
 %                                 March 2000                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -172,6 +172,8 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterARTImage();
   (void) RegisterAVSImage();
   (void) RegisterBMPImage();
+  (void) RegisterBGRImage();
+  (void) RegisterBRAILLEImage();
   (void) RegisterCALSImage();
   (void) RegisterCAPTIONImage();
   (void) RegisterCINImage();
@@ -190,6 +192,9 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterDJVUImage();
 #endif
   (void) RegisterDNGImage();
+#if defined(MAGICKCORE_GVC_DELEGATE)
+  (void) RegisterDOTImage();
+#endif
 #if defined(MAGICKCORE_DPS_DELEGATE)
   (void) RegisterDPSImage();
 #endif
@@ -204,6 +209,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterEXRImage();
 #endif
   (void) RegisterFAXImage();
+  (void) RegisterFDImage();
   (void) RegisterFITSImage();
 #if defined(MAGICKCORE_FPX_DELEGATE)
   (void) RegisterFPXImage();
@@ -223,6 +229,7 @@ MagickExport void RegisterStaticModules(void)
 #if defined(MAGICKCORE_JBIG_DELEGATE)
   (void) RegisterJBIGImage();
 #endif
+  (void) RegisterJNXImage();
 #if defined(MAGICKCORE_JPEG_DELEGATE)
   (void) RegisterJPEGImage();
 #endif
@@ -233,6 +240,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterMACImage();
   (void) RegisterMAGICKImage();
   (void) RegisterMAPImage();
+  (void) RegisterMASKImage();
   (void) RegisterMATImage();
   (void) RegisterMATTEImage();
   (void) RegisterMETAImage();
@@ -247,6 +255,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterNULLImage();
   (void) RegisterOTBImage();
   (void) RegisterPALMImage();
+  (void) RegisterPANGOImage();
   (void) RegisterPATTERNImage();
   (void) RegisterPCDImage();
   (void) RegisterPCLImage();
@@ -269,6 +278,7 @@ MagickExport void RegisterStaticModules(void)
   (void) RegisterPWPImage();
   (void) RegisterRAWImage();
   (void) RegisterRGBImage();
+  (void) RegisterRGFImage();
   (void) RegisterRLAImage();
   (void) RegisterRLEImage();
   (void) RegisterSCRImage();
@@ -346,6 +356,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterARTImage();
   UnregisterAVSImage();
   UnregisterBMPImage();
+  UnregisterBGRImage();
   UnregisterBRAILLEImage();
   UnregisterCALSImage();
   UnregisterCAPTIONImage();
@@ -365,6 +376,9 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterDJVUImage();
 #endif
   UnregisterDNGImage();
+#if defined(MAGICKCORE_GVC_DELEGATE)
+  UnregisterDOTImage();
+#endif
 #if defined(MAGICKCORE_DPS_DELEGATE)
   UnregisterDPSImage();
 #endif
@@ -379,6 +393,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterEXRImage();
 #endif
   UnregisterFAXImage();
+  UnregisterFDImage();
   UnregisterFITSImage();
 #if defined(MAGICKCORE_FPX_DELEGATE)
   UnregisterFPXImage();
@@ -398,6 +413,7 @@ MagickExport void UnregisterStaticModules(void)
 #if defined(MAGICKCORE_JBIG_DELEGATE)
   UnregisterJBIGImage();
 #endif
+  UnregisterJNXImage();
 #if defined(MAGICKCORE_JPEG_DELEGATE)
   UnregisterJPEGImage();
 #endif
@@ -408,6 +424,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterMACImage();
   UnregisterMAGICKImage();
   UnregisterMAPImage();
+  UnregisterMASKImage();
   UnregisterMATImage();
   UnregisterMATTEImage();
   UnregisterMETAImage();
@@ -422,6 +439,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterNULLImage();
   UnregisterOTBImage();
   UnregisterPALMImage();
+  UnregisterPANGOImage();
   UnregisterPATTERNImage();
   UnregisterPCDImage();
   UnregisterPCLImage();
@@ -444,6 +462,7 @@ MagickExport void UnregisterStaticModules(void)
   UnregisterPWPImage();
   UnregisterRAWImage();
   UnregisterRGBImage();
+  UnregisterRGFImage();
   UnregisterRLAImage();
   UnregisterRLEImage();
   UnregisterSCRImage();
