@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -32,6 +32,7 @@ extern ModuleExport size_t
   RegisterAVIImage(void),
   RegisterAVSImage(void),
   RegisterBIEImage(void),
+  RegisterBGRImage(void),
   RegisterBMPImage(void),
   RegisterBRAILLEImage(void),
   RegisterCALSImage(void),
@@ -49,6 +50,7 @@ extern ModuleExport size_t
   RegisterDIBImage(void),
   RegisterDJVUImage(void),
   RegisterDNGImage(void),
+  RegisterDOTImage(void),
   RegisterDPSImage(void),
   RegisterDPXImage(void),
   RegisterEMFImage(void),
@@ -61,6 +63,7 @@ extern ModuleExport size_t
   RegisterEPTImage(void),
   RegisterEXRImage(void),
   RegisterFAXImage(void),
+  RegisterFDImage(void),
   RegisterFITSImage(void),
   RegisterFPXImage(void),
   RegisterG3Image(void),
@@ -82,6 +85,7 @@ extern ModuleExport size_t
   RegisterIPLImage(void),
   RegisterJBGImage(void),
   RegisterJBIGImage(void),
+  RegisterJNXImage(void),
   RegisterJPGImage(void),
   RegisterJPEGImage(void),
   RegisterJP2Image(void),
@@ -89,6 +93,7 @@ extern ModuleExport size_t
   RegisterMACImage(void),
   RegisterMAGICKImage(void),
   RegisterMAPImage(void),
+  RegisterMASKImage(void),
   RegisterMATImage(void),
   RegisterMATTEImage(void),
   RegisterMETAImage(void),
@@ -107,6 +112,7 @@ extern ModuleExport size_t
   RegisterPBMImage(void),
   RegisterOTBImage(void),
   RegisterPALMImage(void),
+  RegisterPANGOImage(void),
   RegisterPATTERNImage(void),
   RegisterPCDImage(void),
   RegisterPCDSImage(void),
@@ -136,6 +142,7 @@ extern ModuleExport size_t
   RegisterRAWImage(void),
   RegisterRGBImage(void),
   RegisterRGBAImage(void),
+  RegisterRGFImage(void),
   RegisterRLAImage(void),
   RegisterRLEImage(void),
   RegisterSCRImage(void),
@@ -185,6 +192,7 @@ extern ModuleExport void
   UnregisterAVIImage(void),
   UnregisterAVSImage(void),
   UnregisterBIEImage(void),
+  UnregisterBGRImage(void),
   UnregisterBMPImage(void),
   UnregisterBRAILLEImage(void),
   UnregisterCALSImage(void),
@@ -202,6 +210,7 @@ extern ModuleExport void
   UnregisterDIBImage(void),
   UnregisterDJVUImage(void),
   UnregisterDNGImage(void),
+  UnregisterDOTImage(void),
   UnregisterDPSImage(void),
   UnregisterDPXImage(void),
   UnregisterEMFImage(void),
@@ -214,6 +223,7 @@ extern ModuleExport void
   UnregisterEPTImage(void),
   UnregisterEXRImage(void),
   UnregisterFAXImage(void),
+  UnregisterFDImage(void),
   UnregisterFITSImage(void),
   UnregisterFPXImage(void),
   UnregisterG3Image(void),
@@ -235,6 +245,7 @@ extern ModuleExport void
   UnregisterIPLImage(void),
   UnregisterJBGImage(void),
   UnregisterJBIGImage(void),
+  UnregisterJNXImage(void),
   UnregisterJPGImage(void),
   UnregisterJPEGImage(void),
   UnregisterJP2Image(void),
@@ -243,6 +254,7 @@ extern ModuleExport void
   UnregisterMACImage(void),
   UnregisterMAGICKImage(void),
   UnregisterMAPImage(void),
+  UnregisterMASKImage(void),
   UnregisterMATImage(void),
   UnregisterMATTEImage(void),
   UnregisterMETAImage(void),
@@ -261,6 +273,7 @@ extern ModuleExport void
   UnregisterPBMImage(void),
   UnregisterOTBImage(void),
   UnregisterPALMImage(void),
+  UnregisterPANGOImage(void),
   UnregisterPATTERNImage(void),
   UnregisterPCDImage(void),
   UnregisterPCDSImage(void),
@@ -290,6 +303,7 @@ extern ModuleExport void
   UnregisterRAWImage(void),
   UnregisterRGBImage(void),
   UnregisterRGBAImage(void),
+  UnregisterRGFImage(void),
   UnregisterRLAImage(void),
   UnregisterRLEImage(void),
   UnregisterSCRImage(void),
