@@ -61,7 +61,7 @@
 */
 #if !defined(MAGICKCORE_HAVE_STRCASECMP) || !defined(MAGICKCORE_HAVE_STRNCASECMP)
 static const unsigned char
-  asciimap[] =
+  AsciiMap[] =
   {
     0x00, 0x01, 0x02, 0x03, 0x04, 0x05, 0x06, 0x07, 0x08, 0x09, 0x0a, 0x0b,
     0x0c, 0x0d, 0x0e, 0x0f, 0x10, 0x11, 0x12, 0x13, 0x14, 0x15, 0x16, 0x17,
@@ -267,7 +267,6 @@ MagickExport char *CloneString(char **destination,const char *source)
   size_t
     length;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(destination != (char **) NULL);
   if (source == (const char *) NULL)
     {
@@ -320,7 +319,6 @@ MagickExport StringInfo *CloneStringInfo(const StringInfo *string_info)
   StringInfo
     *clone_info;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   clone_info=AcquireStringInfo(string_info->length);
@@ -369,7 +367,6 @@ MagickExport int CompareStringInfo(const StringInfo *target,
   int
     status;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(target != (StringInfo *) NULL);
   assert(target->signature == MagickSignature);
   assert(source != (StringInfo *) NULL);
@@ -544,7 +541,6 @@ MagickExport void ConcatenateStringInfo(StringInfo *string_info,
   size_t
     length;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   assert(source != (const StringInfo *) NULL);
@@ -840,7 +836,6 @@ MagickExport char *DestroyString(char *string)
 */
 MagickExport StringInfo *DestroyStringInfo(StringInfo *string_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   if (string_info->datum != (unsigned char *) NULL)
@@ -928,7 +923,6 @@ MagickExport char *EscapeString(const char *source,const char escape)
   size_t
     length;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(source != (const char *) NULL);
   length=strlen(source);
   for (p=source; *p != '\0'; p++)
@@ -993,7 +987,6 @@ MagickExport char *FileToString(const char *filename,const size_t extent,
     length;
 
   assert(filename != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",filename);
   assert(exception != (ExceptionInfo *) NULL);
   return((char *) FileToBlob(filename,extent,&length,exception));
 }
@@ -1114,6 +1107,7 @@ MagickExport ssize_t FormatMagickSize(const MagickSizeType size,
 #endif
   for (i=0; (length >= bytes) && (units[i+1] != (const char *) NULL); i++)
     length/=bytes;
+  count=0;
   for (j=2; j < 12; j++)
   {
     count=FormatLocaleString(format,MaxTextExtent,"%.*g%sB",(int) (i+j),length,
@@ -1734,7 +1728,6 @@ MagickExport void PrintStringInfo(FILE *file,const char *id,
     j;
 
   assert(id != (const char *) NULL);
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",id);
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   p=(char *) string_info->datum;
@@ -1809,7 +1802,6 @@ MagickExport void PrintStringInfo(FILE *file,const char *id,
 */
 MagickExport void ResetStringInfo(StringInfo *string_info)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   (void) ResetMagickMemory(string_info->datum,0,string_info->length);
@@ -1842,7 +1834,6 @@ MagickExport void ResetStringInfo(StringInfo *string_info)
 MagickExport void SetStringInfo(StringInfo *string_info,
   const StringInfo *source)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   assert(source != (StringInfo *) NULL);
@@ -1883,7 +1874,6 @@ MagickExport void SetStringInfo(StringInfo *string_info,
 MagickExport void SetStringInfoDatum(StringInfo *string_info,
   const unsigned char *source)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   if (string_info->length != 0)
@@ -1917,7 +1907,6 @@ MagickExport void SetStringInfoDatum(StringInfo *string_info,
 MagickExport void SetStringInfoLength(StringInfo *string_info,
   const size_t length)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   if (~length < MaxTextExtent)
@@ -1959,7 +1948,6 @@ MagickExport void SetStringInfoLength(StringInfo *string_info,
 */
 MagickExport void SetStringInfoPath(StringInfo *string_info,const char *path)
 {
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   assert(path != (const char *) NULL);
@@ -1994,7 +1982,6 @@ MagickExport StringInfo *SplitStringInfo(StringInfo *string_info,
   StringInfo
     *split_info;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string_info != (StringInfo *) NULL);
   assert(string_info->signature == MagickSignature);
   if (offset > string_info->length)
@@ -2567,7 +2554,6 @@ MagickExport StringInfo *StringToStringInfo(const char *string)
   StringInfo
     *string_info;
 
-  (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(string != (const char *) NULL);
   string_info=AcquireStringInfo(strlen(string));
   SetStringInfoDatum(string_info,(const unsigned char *) string);
