@@ -1072,6 +1072,14 @@ MagickExport MagickBooleanType GetExecutionPath(char *path,const size_t extent)
       program_name=(char *) RelinquishMagickMemory(program_name);
     execution_path=(char *) RelinquishMagickMemory(execution_path);
   }
+#endif
+#if defined(__OpenBSD__)
+  {
+    extern char
+      *__progname;
+
+    (void) CopyMagickString(path,__progname,extent);
+  }
 #endif
   return(IsPathAccessible(path));
 }
