@@ -27,22 +27,22 @@ extern "C" {
 */
 #define MagickPackageName "ImageMagick"
 #define MagickCopyright  "Copyright (C) 1999-2013 ImageMagick Studio LLC"
-#define MagickSVNRevision  "12720"
+#define MagickSVNRevision  "13234"
 #define MagickLibVersion  0x686
 #define MagickLibVersionText  "6.8.6"
 #define MagickLibVersionNumber  1,0,0
-#define MagickLibAddendum  "-6"
+#define MagickLibAddendum  "-10"
 #define MagickLibInterface  1
 #define MagickLibMinInterface  1
 #define MagickppLibVersionText  "6.8.6"
 #define MagickppLibVersionNumber  @MAGICKPP_LIB_VERSION_NUMBER@
-#define MagickppLibAddendum  "-6"
-#define MagickppLibInterface  2
-#define MagickppLibMinInterface  2
-#define MagickReleaseDate  "2013-07-17"
-#define MagickChangeDate   "20130715"
+#define MagickppLibAddendum  "-10"
+#define MagickppLibInterface  3
+#define MagickppLibMinInterface  3
+#define MagickReleaseDate  "2013-09-17"
+#define MagickChangeDate   "20130907"
 #define MagickFeatures "DPC OpenMP"
-#define MagickDelegates "bzlib djvu fftw fontconfig freetype jp2 lzma openexr pango png ps tiff x xml zlib"
+#define MagickDelegates "bzlib djvu fftw fontconfig freetype jp2 lzma openexr pango png ps tiff webp x xml zlib"
 #define MagickHomeURL  "file:///usr/share/doc/ImageMagick-6/index.html"
 #define MagickAuthoritativeURL  "http://www.imagemagick.org"
 #if (MAGICKCORE_QUANTUM_DEPTH == 8)
