@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -24,9 +24,7 @@
 static const char
   *compare_options[] =
   {
-    "",
-    "-compose Src",
-    "-highlight-color SeaGreen",
+    "-metric RMSE -fuzz 5%",
     "-metric AE -fuzz 5%",
     (const char *) NULL
   };
@@ -261,8 +259,8 @@ static const struct ReferenceFormats
     { "GIF", UndefinedCompression, 0.0 },
     { "GIF87", UndefinedCompression, 0.0 },
     { "GRAY", UndefinedCompression, 0.003 },
-    { "HTM", UndefinedCompression, 0.0 },
     { "HRZ", UndefinedCompression, 0.0 },
+    { "HTM", UndefinedCompression, 0.0 },
     { "HTML", UndefinedCompression, 0.0 },
     { "ICB", UndefinedCompression, 0.0 },
     { "ICO", UndefinedCompression, 0.0 },
@@ -271,8 +269,9 @@ static const struct ReferenceFormats
     { "INLINE", UndefinedCompression, 0.0 },
     { "JBG", UndefinedCompression, 0.0 },
     { "JNG", UndefinedCompression, 0.003 },
-    { "JP2", UndefinedCompression, 0.0 },
-    { "JPC", UndefinedCompression, 0.0 },
+    { "JNG", JPEGCompression, 0.003 },
+    { "JP2", UndefinedCompression, 0.003 },
+    { "JPC", UndefinedCompression, 0.003 },
     { "JPEG", UndefinedCompression, 0.003 },
     { "JPG", UndefinedCompression, 0.003 },
     { "K25", UndefinedCompression, 0.0 },
@@ -295,7 +294,7 @@ static const struct ReferenceFormats
     { "PEF", UndefinedCompression, 0.0 },
     { "PFA", UndefinedCompression, 0.0 },
     { "PFB", UndefinedCompression, 0.0 },
-    { "PFM", UndefinedCompression, 0.0 },
+    { "PFM", UndefinedCompression, 0.003 },
     { "PGM", UndefinedCompression, 0.0 },
     { "PGX", UndefinedCompression, 0.0 },
 #if !defined(MAGICKCORE_HDRI_SUPPORT)
@@ -305,8 +304,12 @@ static const struct ReferenceFormats
     { "PJPEG", UndefinedCompression, 0.003 },
     { "PLASMA", UndefinedCompression, 0.0 },
     { "PNG", UndefinedCompression, 0.0 },
+    { "PNG8", UndefinedCompression, 0.0 },
     { "PNG24", UndefinedCompression, 0.0 },
     { "PNG32", UndefinedCompression, 0.0 },
+    { "PNG48", UndefinedCompression, 0.0 },
+    { "PNG64", UndefinedCompression, 0.0 },
+    { "PNG00", UndefinedCompression, 0.0 },
     { "PNM", UndefinedCompression, 0.0 },
     { "PPM", UndefinedCompression, 0.0 },
     { "PREVIEW", UndefinedCompression, 0.0 },
@@ -348,7 +351,7 @@ static const struct ReferenceFormats
     { "X3F", UndefinedCompression, 0.0 },
     { "XBM", UndefinedCompression, 0.0 },
     { "XCF", UndefinedCompression, 0.0 },
-    { "XPM", UndefinedCompression, 0.0 },
+    { "XPM", UndefinedCompression, 0.003 },
     { "XPS", UndefinedCompression, 0.0 },
     { "XV", UndefinedCompression, 0.0 },
 #if !defined(MAGICKCORE_WINDOWS_SUPPORT)
