@@ -304,6 +304,7 @@ static MagickBooleanType CompositeUsage(void)
       "-interpolate method  pixel color interpolation method",
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
+      "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas (setting)",
       "-pointsize value     font point size",
@@ -317,6 +318,7 @@ static MagickBooleanType CompositeUsage(void)
       "-scene value         image scene number",
       "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
+      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-synchronize         synchronize image to storage device",
       "-taint               declare the image as modified",
       "-transparent-color color",
