@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
 
   You may not use this file except in compliance with the License.
@@ -346,10 +346,10 @@ extern WandExport MagickBooleanType
   MagickSpliceImage(MagickWand *,const size_t,const size_t,const ssize_t,
     const ssize_t),
   MagickSpreadImage(MagickWand *,const double),
-  MagickStatisticImage(MagickWand *,const ChannelType,const StatisticType,
-    const size_t,const size_t),
-  MagickStatisticImageChannel(MagickWand *,const StatisticType,const size_t,
+  MagickStatisticImage(MagickWand *,const StatisticType,const size_t,
     const size_t),
+  MagickStatisticImageChannel(MagickWand *,const ChannelType,
+    const StatisticType,const size_t,const size_t),
   MagickStripImage(MagickWand *),
   MagickSwirlImage(MagickWand *,const double),
   MagickTintImage(MagickWand *,const PixelWand *,const PixelWand *),
@@ -374,7 +374,7 @@ extern WandExport MagickBooleanType
   MagickWriteImages(MagickWand *,const char *,const MagickBooleanType),
   MagickWriteImagesFile(MagickWand *,FILE *);
 
-WandExport MagickProgressMonitor
+extern WandExport MagickProgressMonitor
   MagickSetImageProgressMonitor(MagickWand *,const MagickProgressMonitor,
     void *);
 
