@@ -23,7 +23,7 @@
 %                                 August 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2012 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -910,7 +910,7 @@ WandExport void MagickSetFirstIterator(MagickWand *wand)
 %  -1 being the last image in the wand.
 %
 %  If the index is invalid (range too large for number of images in wand)
-%  the function will return magickFalse, but no 'exception' will be raised,
+%  the function will return MagickFalse, but no 'exception' will be raised,
 %  as it is not actually an error.  In that case the current image will not
 %  change.
 %
