@@ -100,7 +100,7 @@ static MagickBooleanType MontageUsage(void)
     {
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
-      " annotate geometry text",
+      "-annotate geometry text",
       "                     annotate the image with text",
       "-auto-orient         automagically orient image",
       "-blur geometry      reduce image noise and reduce detail levels",
@@ -166,6 +166,7 @@ static MagickBooleanType MontageUsage(void)
       "-kerning value       set the space between two letters",
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
+      "-matte               store matte channel if the image has one",
       "-mattecolor color    frame color",
       "-mode type           framing style",
       "-monitor             monitor progress",
@@ -187,6 +188,7 @@ static MagickBooleanType MontageUsage(void)
       "-shadow              add a shadow beneath a tile to simulate depth",
       "-size geometry       width and height of image",
       "-stroke color        color to use when stroking a graphic primitive",
+      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-synchronize         synchronize image to storage device",
       "-taint               declare the image as modified",
       "-texture filename    name of texture to tile onto the image background",
